@@ -8,8 +8,10 @@ import tfkit
 class TestEval(unittest.TestCase):
     ROOT_DIR = os.path.dirname(os.path.abspath(__file__ + "/../../"))
     DATASET_DIR = os.path.join(ROOT_DIR, 'demo_data')
-    ADDED_TOK_MODEL = os.path.join(ROOT_DIR, 'tfkit/test/cache/voidful/albert_chinese_tiny_added_tok')
     ONEBYONE_MODEL_PATH = os.path.join(ROOT_DIR, 'tfkit/test/cache/onebyone/2.pt')
+    ONCE_MODEL_PATH = os.path.join(ROOT_DIR, 'tfkit/test/cache/once/2.pt')
+    ONCECTC_MODEL_PATH = os.path.join(ROOT_DIR, 'tfkit/test/cache/oncectc/30.pt')
+    SEQ2SEQ_MODEL_PATH = os.path.join(ROOT_DIR, 'tfkit/test/cache/seq2seq/10.pt')
     CLAS_MODEL_PATH = os.path.join(ROOT_DIR, 'tfkit/test/cache/clas/2.pt')
     MASK_MODEL_PATH = os.path.join(ROOT_DIR, 'tfkit/test/cache/mask/2.pt')
     MCQ_MODEL_PATH = os.path.join(ROOT_DIR, 'tfkit/test/cache/mcq/2.pt')
@@ -18,9 +20,11 @@ class TestEval(unittest.TestCase):
     TAG_DATASET = os.path.join(DATASET_DIR, 'tag_row.csv')
     CLAS_DATASET = os.path.join(DATASET_DIR, 'classification.csv')
     GEN_DATASET = os.path.join(DATASET_DIR, 'generate.csv')
+    SEQ2SEQ_DATASET = os.path.join(DATASET_DIR, 'gen_eng.csv')
     MASK_DATASET = os.path.join(DATASET_DIR, 'mask.csv')
     MCQ_DATASET = os.path.join(DATASET_DIR, 'mcq.csv')
     QA_DATASET = os.path.join(DATASET_DIR, 'qa.csv')
+    ADDED_TOK_MODEL = os.path.join(ROOT_DIR, 'tfkit/test/cache/voidful/albert_chinese_tiny_added_tok')
 
     def testHelp(self):
         result = os.system('tfkit-eval -h')
@@ -39,6 +43,27 @@ class TestEval(unittest.TestCase):
             'tfkit-eval --model ' + self.ONEBYONE_MODEL_PATH + ' --valid ' + self.GEN_DATASET + ' --metric emf1 --print')
         self.assertTrue(result == 0)
 
+    def testEvalGenOnce(self):
+        tfkit.eval.main(
+            ['--model', self.ONCE_MODEL_PATH, '--valid', self.GEN_DATASET, '--metric', 'emf1', '--print'])
+        result = os.system(
+            'tfkit-eval --model ' + self.ONCE_MODEL_PATH + ' --valid ' + self.GEN_DATASET + ' --metric emf1 --print')
+        self.assertTrue(result == 0)
+
+    def testEvalGenOnceCTC(self):
+        tfkit.eval.main(
+            ['--model', self.ONCECTC_MODEL_PATH, '--valid', self.SEQ2SEQ_DATASET, '--metric', 'emf1', '--print'])
+        result = os.system(
+            'tfkit-eval --model ' + self.ONCECTC_MODEL_PATH + ' --valid ' + self.SEQ2SEQ_DATASET + ' --metric emf1 --print')
+        self.assertTrue(result == 0)
+
+    def testEvalSeq2Seq(self):
+        tfkit.eval.main(
+            ['--model', self.SEQ2SEQ_MODEL_PATH, '--valid', self.SEQ2SEQ_DATASET, '--metric', 'emf1', '--print'])
+        result = os.system(
+            'tfkit-eval --model ' + self.SEQ2SEQ_MODEL_PATH + ' --valid ' + self.SEQ2SEQ_DATASET + ' --metric emf1 --print')
+        self.assertTrue(result == 0)
+
     def testEvalMask(self):
         tfkit.eval.main(
             ['--model', self.MASK_MODEL_PATH, '--valid', self.MASK_DATASET, '--metric', 'clas', '--print'])
